@@ -29,7 +29,7 @@ class TrelloCog(commands.Cog):
 
     @app_commands.command(name="trello_add")
     @app_commands.autocomplete(trello_list=trello_lists_list)
-    @commands.has_role("Shiny")
+    @app_commands.checks.has_role("Shiny")
     async def trello_add(self, context: discord.Interaction, card_name: str, trello_list: str = config.TRELLO_LIST_DEFAULT):
         """Add card to Trello list"""
         await context.response.defer()
@@ -43,7 +43,7 @@ class TrelloCog(commands.Cog):
 
     @app_commands.command(name="trello_list")
     @app_commands.autocomplete(trello_list=trello_lists_list)
-    @commands.has_role("Shiny")
+    @app_commands.checks.has_role("Shiny")
     async def trello_list(self, context: discord.Interaction, trello_list: str = config.TRELLO_LIST_DEFAULT):
         """Get cards from Trello list"""
         await context.response.defer()
