@@ -37,18 +37,21 @@ class Vacuum(HomeAssistant):
         self.domain = "vacuum"
         super().__init__(entity_id=entity_id, *args, **kwargs)
 
-    def start(self):
+    def suck(self) -> str:
         """Start vacuum cleaner"""
         self.client.get_domain(self.domain).start(entity_id=self.entity_id)
+        return "starting"
 
-    def stop(self):
+    def stop(self) -> str:
         """Return vacuum cleaner to base"""
         print(f"{self.entity_id}|{self.domain}")
         self.client.get_domain(self.domain).stop(entity_id=self.entity_id)
+        return "stopping"
 
-    def go_home(self):
+    def go_home(self) -> str:
         """Return vacuum cleaner to base"""
         self.client.get_domain(self.domain).return_to_base(entity_id=self.entity_id)
+        return "going home"
 
 
 class InputBoolean(HomeAssistant):
@@ -78,13 +81,15 @@ class Alarm(HomeAssistant):
         self.domain = "alarm_control_panel"
         super().__init__(entity_id=entity_id, *args, **kwargs)
 
-    def arm(self):
+    def arm(self) -> str:
         """Arm alarm panel"""
         self.client.get_domain(self.domain).alarm_arm_away(entity_id=self.entity_id)
+        return "arming"
 
-    def disarm(self):
+    def disarm(self) -> str:
         """Arm alarm panel"""
         self.client.get_domain(self.domain).alarm_disarm(entity_id=self.entity_id)
+        return "disarming"
 
 
 class Lock(HomeAssistant):
@@ -94,13 +99,15 @@ class Lock(HomeAssistant):
         self.domain = "lock"
         super().__init__(*args, **kwargs)
 
-    def lock(self):
+    def lock(self) -> str:
         """Lock door"""
         self.client.get_domain(self.domain).lock(entity_id=self.entity_id)
+        return "locking"
 
-    def unlock(self):
+    def unlock(self) -> str:
         """Unlock door"""
         self.client.get_domain(self.domain).unlock(entity_id=self.entity_id)
+        return "unlocking"
 
 
 class Sensor(HomeAssistant):
